"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const _fp = require("lodash/fp");
function tryInvoke(object, path, args, defaultValue) {
    const f = _.get(object, path, null);
    return _.isFunction(f)
        ? f(...args)
        : defaultValue;
}
exports.tryInvoke = tryInvoke;
function mergeObjectWithConcat(source1, source2) {
    return _.mergeWith(source1, source2, (objValue, srcValue) => {
        if (_.isArray(objValue)) {
            return objValue.concat(srcValue);
        }
        return undefined;
    });
}
exports.mergeObjectWithConcat = mergeObjectWithConcat;
function random() {
    return Math.random();
}
exports.random = random;
function safePathGet(object, path, defaultValue = null) {
    const value = !_.isEmpty(path)
        ? _.get(object, path)
        : object;
    return value != null
        ? value
        : defaultValue;
}
exports.safePathGet = safePathGet;
function safeInsertValueToPath(value, path, object = {}) {
    return !_.isEmpty(path)
        ? _.set(object, path, value)
        : value;
}
exports.safeInsertValueToPath = safeInsertValueToPath;
function setToObjectFp(originalValue, valueToInsert, pathInResult) {
    return !_.isEmpty(pathInResult)
        ? _fp.set(pathInResult, valueToInsert, originalValue)
        : Object.assign({}, originalValue, valueToInsert);
}
exports.setToObjectFp = setToObjectFp;
function dotify(obj) {
    const res = {};
    function recurse(obj, current = undefined) {
        for (let key in obj) {
            const value = obj[key];
            const newKey = (current ? `${current}.${key}` : key);
            if (value && typeof value === 'object') {
                recurse(value, newKey);
            }
            else {
                res[newKey] = value;
            }
        }
    }
    recurse(obj);
    return res;
}
exports.dotify = dotify;
//# sourceMappingURL=HelperFunctions.js.map