"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const HelperFunctions_1 = require("../lib/HelperFunctions");
function buildReadWriteObjectMapper(setValueToObj, extend = null) {
    return {
        globalMapper: (value, path, rootValue) => (Object.assign({}, HelperFunctions_1.tryInvoke(extend, 'globalMapper', [value, path, rootValue], {}), { path,
            value, setValue: (newValue) => {
                setValueToObj(newValue, path);
            }, getValue: (path, defaultValue) => {
                const valueAtPath = _.isEmpty(path)
                    ? value
                    : _.get(value, path);
                return valueAtPath != null
                    ? valueAtPath
                    : defaultValue;
            }, getValueFromRoot: (path, defaultRootValue) => {
                const valueAtPath = _.isEmpty(path)
                    ? rootValue
                    : defaultRootValue;
                return valueAtPath != null
                    ? valueAtPath
                    : defaultRootValue;
            } })),
        arrayMapper: (value, path, rootValue) => (Object.assign({}, HelperFunctions_1.tryInvoke(extend, 'arrayMapper', [value, path, rootValue], {}), { addOrPushItem: (itemToPush = null, index) => {
                const newArrayValue = _.isArray(value) ? [...value] : [];
                if (index == null) {
                    newArrayValue.push(itemToPush);
                }
                else {
                    _.set(newArrayValue, index, itemToPush);
                }
                setValueToObj(newArrayValue, path);
            }, removeOrPopItem: (index) => {
                const newArrayValue = _.isArray(value) ? [...value] : [];
                if (index == null) {
                    newArrayValue.pop();
                }
                else {
                    newArrayValue.splice(index, 1);
                }
                setValueToObj(newArrayValue, path);
            } })),
        objectMapper: (value, path, rootValue) => (Object.assign({}, HelperFunctions_1.tryInvoke(extend, 'objectMapper', [value, path, rootValue], {}))),
        primitiveMapper: (value, path, rootValue) => (Object.assign({}, HelperFunctions_1.tryInvoke(extend, 'primitiveMapper', [value, path, rootValue], {}))),
    };
}
exports.buildReadWriteObjectMapper = buildReadWriteObjectMapper;
function parseAndSetDataInObjectPurely(initialState, initialValue, path, objectMapper) {
    const expandedValue = _.set({}, path, initialValue);
    const parsedValue = objectMapper != null
        ? objectMapper.parse(expandedValue)
        : expandedValue;
    const value = _.get(parsedValue, path, initialValue);
    const newState = HelperFunctions_1.setToObjectFp(initialState, value, path);
    return newState;
}
exports.parseAndSetDataInObjectPurely = parseAndSetDataInObjectPurely;
//# sourceMappingURL=ReadWriteObjectMapper.js.map